@@ -1,12 +1,10 @@
 package Parse::ErrorString::Perl;
 
-# ABSTRACT: Parse error messages from the perl interpreter
-
 use v5.8.7;
 use strict;
 use warnings;
 
-our $VERSION = '0.19';
+our $VERSION = '0.20';
 
 use Carp qw(carp cluck);
 use Pod::Find ();
@@ -489,25 +487,41 @@ You can find documentation for this module with the perldoc command.
 
     perldoc Parse::ErrorString::Perl
 
+=head1 AUTHOR
 
-=over 4
+Petar Shangov, <pshangov at yahoo.com>
 
-=item * RT: CPAN's request tracker
+=head1 COPYRIGHT
 
-L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Parse-ErrorString-Perl>
+Copyright 2008-2013 The Padre development team as listed in Padre.pm.
+L<http://padre.perlide.org/>
 
-=item * AnnoCPAN: Annotated CPAN documentation
+=head1 LICENSE
 
-L<http://annocpan.org/dist/Parse-ErrorString-Perl>
+This program is free software; you can redistribute it and/or
+modify it under the same terms as Perl 5 itself.
 
-=item * CPAN Ratings
+=head1 DISCLAIMER OF WARRANTY
 
-L<http://cpanratings.perl.org/d/Parse-ErrorString-Perl>
+BECAUSE THIS SOFTWARE IS LICENSED FREE OF CHARGE, THERE IS NO WARRANTY
+FOR THE SOFTWARE, TO THE EXTENT PERMITTED BY APPLICABLE LAW. EXCEPT WHEN
+OTHERWISE STATED IN WRITING THE COPYRIGHT HOLDERS AND/OR OTHER PARTIES
+PROVIDE THE SOFTWARE "AS IS" WITHOUT WARRANTY OF ANY KIND, EITHER
+EXPRESSED OR IMPLIED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
+WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE. THE
+ENTIRE RISK AS TO THE QUALITY AND PERFORMANCE OF THE SOFTWARE IS WITH
+YOU. SHOULD THE SOFTWARE PROVE DEFECTIVE, YOU ASSUME THE COST OF ALL
+NECESSARY SERVICING, REPAIR, OR CORRECTION.
 
-=item * Search CPAN
-
-L<http://search.cpan.org/dist/Parse-ErrorString-Perl/>
-
-=back
+IN NO EVENT UNLESS REQUIRED BY APPLICABLE LAW OR AGREED TO IN WRITING
+WILL ANY COPYRIGHT HOLDER, OR ANY OTHER PARTY WHO MAY MODIFY AND/OR
+REDISTRIBUTE THE SOFTWARE AS PERMITTED BY THE ABOVE LICENCE, BE
+LIABLE TO YOU FOR DAMAGES, INCLUDING ANY GENERAL, SPECIAL, INCIDENTAL,
+OR CONSEQUENTIAL DAMAGES ARISING OUT OF THE USE OR INABILITY TO USE
+THE SOFTWARE (INCLUDING BUT NOT LIMITED TO LOSS OF DATA OR DATA BEING
+RENDERED INACCURATE OR LOSSES SUSTAINED BY YOU OR THIRD PARTIES OR A
+FAILURE OF THE SOFTWARE TO OPERATE WITH ANY OTHER SOFTWARE), EVEN IF
+SUCH HOLDER OR OTHER PARTY HAS BEEN ADVISED OF THE POSSIBILITY OF
+SUCH DAMAGES.
 
 =cut
